Commands

Enum Commands 

pub enum Commands {
Show 19 variants Show { id: u32, follow: bool, body: bool, }, List { type: Option<String>, grep: Option<String>, case_sensitive: bool, exact_match: bool, regex_mode: bool, }, Refs { id: u32, follow: bool, }, Links { id: u32, follow: bool, }, Search { query: String, case_sensitive: bool, exact_match: bool, regex_mode: bool, follow: bool, }, Add { type: Option<String>, title: Option<String>, body: Option<String>, strict: bool, }, Deprecate { id: u32, to: u32, }, Edit { id: u32, }, Patch { id: u32, type: Option<String>, title: Option<String>, body: Option<String>, strict: bool, }, Put { id: u32, line: String, strict: bool, }, Verify { id: u32, }, Delete { id: u32, force: bool, }, Lint { fix: bool, }, Orphans { with_descriptions: bool, }, Type { of: Option<String>, }, Relationships { id: u32, follow: bool, }, Graph { id: u32, follow: bool, }, Prime, Batch { input: Option<PathBuf>, format: String, dry_run: bool, fix: bool, },
}

Variants



Show

Show a node by ID (displays incoming and outgoing references)

Fields

id: u32

Node ID

follow: bool

Follow external references across files

body: bool

Print the found node’s body only



List

List nodes (optionally filtered by –type or –grep with search flags)

Fields

type: Option<String>

Filter by node type prefix (case-sensitive, e.g., AE, WF, DOC)

grep: Option<String>

Filter by substring (default: case-insensitive substring match)

case_sensitive: bool

Match case exactly (default: case-insensitive)

exact_match: bool

Match entire words/phrases exactly (default: substring match)

regex_mode: bool

Use regex pattern instead of plain text



Refs

Show nodes that REFERENCE (← INCOMING) the given ID

Fields

id: u32

Node ID to find incoming references for

follow: bool

Follow external references across files

Show nodes that the given ID REFERENCES (→ OUTGOING)

Fields

id: u32

Node ID to find outgoing references from

follow: bool

Follow external references across files



Search

Search nodes by substring (case-insensitive, alias: mindmap-cli search = mindmap-cli list –grep) Search nodes by substring (case-insensitive by default, use flags for advanced search)

Fields

query: String

Search query (searches title and body)

case_sensitive: bool

Match case exactly (default: case-insensitive)

exact_match: bool

Match entire words/phrases exactly (default: substring match)

regex_mode: bool

Use regex pattern instead of plain text

follow: bool

Follow external references across files



Add

Add a new node

Fields

strict: bool

When using editor flow, perform strict reference validation



Deprecate

Deprecate a node, redirecting to another

Fields

id: u32
to: u32


Edit

Edit a node with $EDITOR

Fields

id: u32


Patch

Patch (partial update) a node: –type, –title, –body

Fields

id: u32
strict: bool


Put

Put (full-line replace) a node: –line

Fields

id: u32
line: String
strict: bool


Verify

Mark a node as needing verification (append verify tag)

Fields

id: u32


Delete

Delete a node by ID; use –force to remove even if referenced

Fields

id: u32
force: bool


Lint

Lint the mindmap for basic issues (use –fix to auto-fix spacing and type prefixes)

Fields

fix: bool

Auto-fix spacing and duplicated type prefixes



Orphans

Show orphan nodes (no in & no out, excluding META)

Fields

with_descriptions: bool

Include node descriptions in output



Type

Show all node types in use with statistics and frequency

Fields

of: Option<String>

Show details for a specific type (e.g., AE, WF, DR)



Relationships

Show incoming and outgoing references for a node in one view

Fields

id: u32

Node ID to show relationships for

follow: bool

Follow external references across files



Graph

Show graph neighborhood for a node (DOT format for Graphviz)

Fields

id: u32

Node ID

follow: bool

Follow external references across files



Prime

Prime: print help and list to prime an AI agent’s context



Batch

Batch mode: apply multiple non-interactive commands atomically

Fields

input: Option<PathBuf>

Input file with commands (one per line) or ‘-’ for stdin

format: String

Input format: ‘lines’ or ‘json’

dry_run: bool

Do not write changes; just show what would happen

fix: bool

Apply auto-fixes (spacing / duplicated type prefixes) before saving